@@ -29,13 +29,7 @@ config = dict(
         # infrastructure's bus.  Cool, right?  :)
         "fedora-infrastructure": [
             "tcp://hub.fedoraproject.org:9940",
-            "tcp://hub.stg.fedoraproject.org:9940",
-        ],
-
-        # This is the output side of the relay to which all other
-        # services can listen.
-        "relay_outbound": [
-            "tcp://*:4001",
+            "tcp://stg.fedoraproject.org:9940",
         ],
 
         # For other, more 'normal' services, fedmsg will try to guess the
@@ -49,14 +43,4 @@ config = dict(
         "pkgdb.%s" % hostname: ["tcp://*:3005"],
         "busmon.%s" % hostname: ["tcp://*:3006"],
     },
-
-    # This is the address of an active->passive relay.  It is used for the
-    # fedmsg-logger command which requires another service with a stable
-    # listening address for it to send messages to.
-    # It is also used by the git-hook, for the same reason.
-    # It is also used by the mediawiki php plugin which, due to the oddities of
-    # php, can't maintain a single passive-bind endpoint of it's own.
-    relay_inbound=[
-        "tcp://127.0.0.1:2003",
-    ],
 )
