@@ -26,8 +26,30 @@ class BaseProcessor(object):
     Override handle_{title,subtitle,link,icon} to use.
     """
 
+    # These five properties must be overridden by child-classes.
+    # They can be used by applications to give more context to messages.  If
+    # the BodhiProcessor can handle a message, then our caller's code can use
+    # these attributes to say "btw, this message is from Bodhi, the Fedora
+    # update system.  It lives at https://admin.fedoraproject.org/updates/
+    # and you can read more about it at http://fedoraproject.org/wiki/Bodhi"
+    __name__ = None
+    __description__ = None
+    __link__ = None
+    __docs__ = None
+    __obj__ = None
+
     def __init__(self, internationalization_callable):
         self._ = internationalization_callable
+        if not self.__name__:
+            raise ValueError("Must declare a __name__")
+        if not self.__description__:
+            raise ValueError("Must declare a __description__")
+        if not self.__link__:
+            raise ValueError("Must declare a __link__")
+        if not self.__docs__:
+            raise ValueError("Must declare a __docs__")
+        if not self.__obj__:
+            raise ValueError("Must declare a __obj__")
 
     def handle_title(self, msg, **config):
         """ Return true if this processor can produce a "title" for this
@@ -96,3 +118,20 @@ class BaseProcessor(object):
         This is only called if :meth:`handle_icon` returned True.
         """
         raise NotImplementedError
+
+    def handle_secondary_icon(self, msg, **config):
+        """ Return true if this processor can produce a "secondary icon" for
+        this message.
+
+        For this base class, this always returns ``False``.  Override it to
+        return True in situations for which your :meth:`icon` method can
+        produce a icon.
+        """
+        return False
+
+    def secondary_icon(self, msg, **config):
+        """ Return a "secondary icon" for the message.
+
+        This is only called if :meth:`handle_icon` returned True.
+        """
+        raise NotImplementedError
