@@ -16,11 +16,19 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 # Authors:  Ralph Bean <rbean@redhat.com>
-#
+#           Luke Macken <lmacken@redhat.com>
+
 from fedmsg.text.base import BaseProcessor
+from fedmsg.text.fasshim import gravatar_url
 
 
 class BodhiProcessor(BaseProcessor):
+    __name__ = "Bodhi"
+    __description__ = "the Fedora update system"
+    __link__ = "https://admin.fedoraproject.org/updates"
+    __docs__ = "http://fedoraproject.org/wiki/Bodhi"
+    __obj__ = "Package Updates"
+
     def handle_subtitle(self, msg, **config):
         return any([target in msg['topic'] for target in [
             'bodhi.update.comment',
@@ -43,11 +51,31 @@ class BodhiProcessor(BaseProcessor):
         ]])
 
     def handle_icon(self, msg, **config):
-        return True
+        return any([target in msg['topic'] for target in [
+            'bodhi.update',
+            'bodhi.mashtask',
+            'bodhi.buildroot_override',
+        ]])
 
     def icon(self, msg, **config):
         return "https://admin.fedoraproject.org/updates" + \
-                "/static/images/bodhi-icon-48.png"
+               "/static/images/bodhi-icon-48.png"
+
+    def handle_secondary_icon(self, msg, **config):
+        return self.handle_icon(msg, **config)
+
+    def secondary_icon(self, msg, **config):
+        username = ''
+        if 'bodhi.update.comment' in msg['topic']:
+            username = msg['msg']['comment']['author']
+        elif 'bodhi.buildroot_override' in msg['topic']:
+            username = msg['msg']['override']['submitter']
+        else:
+            username = msg['msg'].get('update', {}).get('submitter')
+        gravatar = ''
+        if username:
+            gravatar = gravatar_url(username)
+        return gravatar
 
     def subtitle(self, msg, **config):
         if 'bodhi.update.comment' in msg['topic']:
